summaryrefslogtreecommitdiff
path: root/src/location/qgeosatelliteinfosource_npe_backend.cpp
diff options
context:
space:
mode:
authorCarsten Bürger <carsten.burger@nokia.com>2011-11-15 16:10:24 +0100
committerQt by Nokia <qt-info@nokia.com>2011-11-16 01:41:07 +0100
commit1ab734248cba1c08e5e095be5a97dd1042b212be (patch)
tree7a12a925dfc305b7b8bf987731a56330700f89a8 /src/location/qgeosatelliteinfosource_npe_backend.cpp
parentfcf175d3db39a013cd9aa2ac29f11fd04b400701 (diff)
downloadqtlocation-1ab734248cba1c08e5e095be5a97dd1042b212be.tar.gz
renaming nld into locationd
Change-Id: I9c207594d025a86729df300b3ad128574951aecb Reviewed-by: Alex <alex.blasche@nokia.com>
Diffstat (limited to 'src/location/qgeosatelliteinfosource_npe_backend.cpp')
-rw-r--r--src/location/qgeosatelliteinfosource_npe_backend.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/location/qgeosatelliteinfosource_npe_backend.cpp b/src/location/qgeosatelliteinfosource_npe_backend.cpp
index 4b90e32a..8717c7b7 100644
--- a/src/location/qgeosatelliteinfosource_npe_backend.cpp
+++ b/src/location/qgeosatelliteinfosource_npe_backend.cpp
@@ -43,13 +43,13 @@
#include <sys/stat.h>
// API for socket communication towards nld
const QString ksatelliteStartUpdates = QLatin1String("satelliteStartUpdates");
const QString ksatelliteRequestUpdate = QLatin1String("satelliteRequestUpdate");
const QString ksatelliteStopUpdates = QLatin1String("satelliteStopUpdates");
const QString ksatelliteInfoUpdate = QLatin1String("satelliteInfoUpdate");
// Attributes for socket communication towards nld
const QString ksatId = QLatin1String("satId");
const QString kazimuth = QLatin1String("azimuth");
const QString kelevation = QLatin1String("elevation");
@@ -78,7 +78,7 @@ QGeoSatelliteInfoSourceNpeBackend::QGeoSatelliteInfoSourceNpeBackend(QObject *pa
bool QGeoSatelliteInfoSourceNpeBackend::init()
{
struct stat buf;
- if (stat("/var/run/nld/nld.socket", &buf) == 0) {
+ if (stat("/var/run/locationd/locationd.socket", &buf) == 0) {
mSocket = new QLocalSocket(this);
if (mSocket) {
connect(mSocket, SIGNAL(connected()), this, SLOT(onSocketConnected()));
@@ -87,7 +87,7 @@ bool QGeoSatelliteInfoSourceNpeBackend::init()
if (mStream) {
connect(mStream, SIGNAL(receive(const QVariantMap&)), this, SLOT(onStreamReceived(const QVariantMap&)), Qt::QueuedConnection);
}
- mSocket->connectToServer("/var/run/nld/nld.socket");
+ mSocket->connectToServer("/var/run/locationd/locationd.socket");
return(mSocket->waitForConnected(500)); // wait up to 0.5 seconds to get connected, otherwise return false
}
}
@@ -144,7 +144,7 @@ void QGeoSatelliteInfoSourceNpeBackend::requestTimerExpired()
void QGeoSatelliteInfoSourceNpeBackend::onStreamReceived(const QVariantMap& map)
{
// this slot handles the communication received from nld socket
if (map.contains(JsonDbString::kActionStr)) {
QString action = map.value(JsonDbString::kActionStr).toString();
@@ -43,13 +43,13 @@
#include <sys/stat.h>
-// API for socket communication towards nld
+// API for socket communication towards locationd
const QString ksatelliteStartUpdates = QLatin1String("satelliteStartUpdates");
const QString ksatelliteRequestUpdate = QLatin1String("satelliteRequestUpdate");
@@ -43,13 +43,13 @@
const QString ksatelliteStopUpdates = QLatin1String("satelliteStopUpdates");
const QString ksatelliteInfoUpdate = QLatin1String("satelliteInfoUpdate");
-// Attributes for socket communication towards nld
+// Attributes for socket communication towards locationd
const QString ksatId = QLatin1String("satId");
const QString kazimuth = QLatin1String("azimuth");
@@ -144,7 +144,7 @@ void QGeoSatelliteInfoSourceNpeBackend::requestTimerExpired()
void QGeoSatelliteInfoSourceNpeBackend::onStreamReceived(const QVariantMap& map)
{
- // this slot handles the communication received from nld socket
+ // this slot handles the communication received from locationd socket
if (map.contains(JsonDbString::kActionStr)) {
QString action = map.value(JsonDbString::kActionStr).toString();